pyqode.core.backend package
===========================

.. toctree::
   :maxdepth: 4

Module content
--------------

.. automodule:: pyqode.core.backend


Classes
-------

CodeCompletionWorker
++++++++++++++++++++

.. autoclass:: pyqode.core.backend.CodeCompletionWorker
    :members:
    :undoc-members:
    :show-inheritance:

DocumentWordsProvider
+++++++++++++++++++++

.. autoclass:: pyqode.core.backend.DocumentWordsProvider
    :members:
    :undoc-members:
    :show-inheritance:

JsonServer
++++++++++

.. autoclass:: pyqode.core.backend.JsonServer
    :members:
    :undoc-members:
    :show-inheritance:

NotConnected
++++++++++++

.. autoclass:: pyqode.core.backend.NotConnected
    :members:
    :undoc-members:
    :show-inheritance:

NotRunning
++++++++++

.. autoclass:: pyqode.core.backend.NotRunning
    :members:
    :undoc-members:
    :show-inheritance:

Functions
---------

default_parser
++++++++++++++

.. autofunction:: pyqode.core.backend.default_parser

serve_forever
+++++++++++++

.. autofunction:: pyqode.core.backend.serve_forever


echo_worker
+++++++++++

.. autofunction:: pyqode.core.backend.echo_worker

